pub async fn create_dashboard(
storage: StorageManager,
orchestrator: Orchestrator,
) -> Result<WebDashboard>Expand description
Create a new web dashboard with the given storage and orchestrator
pub async fn create_dashboard(
storage: StorageManager,
orchestrator: Orchestrator,
) -> Result<WebDashboard>Create a new web dashboard with the given storage and orchestrator