pub async fn run_default(
storage: StorageManager,
orchestrator: Orchestrator,
) -> Result<()>Expand description
Run the web dashboard on the default port (8768)
pub async fn run_default(
storage: StorageManager,
orchestrator: Orchestrator,
) -> Result<()>Run the web dashboard on the default port (8768)